==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/shared/qbs/src/lib/corelib/buildgraph/rawscanneddependency.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "rawscanneddependency.h"

#include <tools/fileinfo.h>
#include <tools/persistence.h>

namespace qbs {
namespace Internal {

RawScannedDependency::RawScannedDependency() : m_isClean(true) {}

RawScannedDependency::RawScannedDependency(const QString &filePath)
{
    FileInfo::splitIntoDirectoryAndFileName(filePath, &m_dirPath, &m_fileName);
    setClean();
}

QString RawScannedDependency::filePath() const
{
    return m_dirPath.isEmpty() ? m_fileName : m_dirPath + QLatin1Char('/') + m_fileName;
}

void RawScannedDependency::setClean()
{
    m_isClean = !m_dirPath.contains(QLatin1Char('.')) && !m_dirPath.contains(QLatin1String("//"));
}

void RawScannedDependency::load(PersistentPool &pool)
{
    pool.load(m_dirPath);
    pool.load(m_fileName);
    setClean();
}

void RawScannedDependency::store(PersistentPool &pool) const
{
    pool.store(m_dirPath);
    pool.store(m_fileName);
}

bool operator==(const RawScannedDependency &d1, const RawScannedDependency &d2)
{
    return d1.dirPath() == d2.dirPath() && d1.fileName() == d2.fileName();
}


} // namespace Internal
} // namespace qbs

==> qtcreator_19.0.0~rc1.orig.tar.xz: qt-creator-opensource-src-19.0.0-rc1/src/shared/qbs/src/lib/corelib/buildgraph/rawscanneddependency.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "rawscanneddependency.h"

#include <tools/fileinfo.h>

namespace qbs {
namespace Internal {

RawScannedDependency::RawScannedDependency() : m_isClean(true) {}

RawScannedDependency::RawScannedDependency(const QString &filePath)
{
    FileInfo::splitIntoDirectoryAndFileName(filePath, &m_dirPath, &m_fileName);
    setClean();
}

QString RawScannedDependency::filePath() const
{
    return m_dirPath.isEmpty() ? m_fileName : m_dirPath + QLatin1Char('/') + m_fileName;
}

void RawScannedDependency::setClean()
{
    m_isClean = !m_dirPath.contains(QLatin1Char('.')) && !m_dirPath.contains(QStringLiteral("//"));
}

void RawScannedDependency::load(PersistentPool &pool)
{
    serializationOp<PersistentPool::Load>(pool);
    setClean();
}

void RawScannedDependency::store(PersistentPool &pool)
{
    serializationOp<PersistentPool::Store>(pool);
}

bool operator==(const RawScannedDependency &d1, const RawScannedDependency &d2)
{
    return d1.dirPath() == d2.dirPath() && d1.fileName() == d2.fileName();
}


} // namespace Internal
} // namespace qbs
